[Openmp-commits] [openmp] r263291 - [STATS] change TASK_execution name to OMP_task

Jonathan Peyton via Openmp-commits openmp-commits at lists.llvm.org
Fri Mar 11 12:23:06 PST 2016


Author: jlpeyton
Date: Fri Mar 11 14:23:05 2016
New Revision: 263291

URL: http://llvm.org/viewvc/llvm-project?rev=263291&view=rev
Log:
[STATS] change TASK_execution name to OMP_task

Modified:
    openmp/trunk/runtime/src/kmp_stats.h
    openmp/trunk/runtime/src/kmp_tasking.c

Modified: openmp/trunk/runtime/src/kmp_stats.h
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/runtime/src/kmp_stats.h?rev=263291&r1=263290&r2=263291&view=diff
==============================================================================
--- openmp/trunk/runtime/src/kmp_tasking.c (original)
+++ openmp/trunk/runtime/src/kmp_tasking.c Fri Mar 11 14:23:05 2016
@@ -1166,7 +1166,7 @@ __kmp_invoke_task( kmp_int32 gtid, kmp_t
     //
     if (!discard) {
         KMP_COUNT_BLOCK(TASK_executed);
-        KMP_TIME_BLOCK (TASK_execution);
+        KMP_TIME_BLOCK (OMP_task);
 #endif // OMP_40_ENABLED
 
 #if OMPT_SUPPORT && OMPT_TRACE




More information about the Openmp-commits mailing list
--- openmp/trunk/runtime/src/kmp_stats.h (original)
+++ openmp/trunk/runtime/src/kmp_stats.h Fri Mar 11 14:23:05 2016
@@ -114,7 +114,7 @@ class stats_flags_e {
     macro (OMP_barrier, 0, arg)                                 \
     macro (FOR_static_scheduling, 0, arg)                       \
     macro (FOR_dynamic_scheduling, 0, arg)                      \
-    macro (TASK_execution, 0, arg)                              \
+    macro (OMP_task,   0, arg)                                  \
     macro (OMP_single, 0, arg)                                  \
     macro (OMP_master, 0, arg)                                  \
     macro (OMP_set_numthreads, stats_flags_e::noUnits, arg)     \
@@ -129,7 +129,7 @@ class stats_flags_e {
 // OMP_serial             -- thread zero time executing serial code
 // OMP_work               -- elapsed time in code dispatched by a fork (measured in the thread)
 // OMP_barrier            -- time at "real" barriers (includes task time)
 // TASK_execution         -- time spent executing tasks
 // FOR_static_iterations  -- Available parallelism in statically scheduled for loops
 // FOR_dynamic_iterations -- Available parallelism in dynamically scheduled for loops
 // FOR_static_scheduling  -- time spent doing scheduling for a static "for"
@@ -129,7 +129,7 @@ class stats_flags_e {
 // OMP_work               -- elapsed time in code dispatched by a fork (measured in the thread)
 // OMP_barrier            -- time at "real" barriers (includes task time)
-// TASK_execution         -- time spent executing tasks
+// OMP_task               -- time spent executing tasks
 // FOR_static_iterations  -- Available parallelism in statically scheduled for loops
 // FOR_dynamic_iterations -- Available parallelism in dynamically scheduled for loops

Modified: openmp/trunk/runtime/src/kmp_tasking.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/runtime/src/kmp_tasking.c?rev=263291&r1=263290&r2=263291&view=diff
==============================================================================